@@ -1,28 +1,33 @@
 //! # webster-rs
 //! A Rust library containing an offline version of webster's dictionary.
 //!
+//! ```
+//! webster = 0.2.0
+//! ```
+//!
 //! ```rust
-//! use webster::dictionary;
-//!
 //! fn main() {
-//!     let word = dictionary("computer").unwrap();
+//!     let word = "silence";
 //!
-//!     println!("computer definition: {}", word);
+//!     let definition = webster::definition(word).unwrap();
+//!
+//!     println!("{} definition: {}", word, definition);
 //! }
 //! ```
 //!
 //! The definitions are not *great* but they'll do for simple projects if you need an open source local dictionary API.
 
+#[macro_use]
+extern crate lazy_static;
 use serde_json::Value;
 
-/// Translate a word
-pub fn dictionary<T: AsRef<str>>(word: T) -> Option<String> {
-    let dict: Value = match serde_json::from_str(include_str!("dictionary.json")) {
-        Ok(data) => data,
-        Err(_) => return None,
-    };
+lazy_static! {
+    pub static ref DICT: Value = serde_json::from_str(include_str!("dictionary.json")).unwrap_or(Value::from(""));
+}
 
-    match &dict[word.as_ref().to_uppercase()] {
+/// Translate a word
+pub fn definition<T: AsRef<str>>(word: T) -> Option<String> {
+    match &DICT[word.as_ref().to_uppercase()] {
         Value::String(string) => return Some(string.to_string()),
         &_ => return None,
     }
